==> lxqt-powermanagement_0.14.1.orig.tar.xz: lxqt-powermanagement-0.14.1/config/translations/lxqt-config-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Einstellungen zur Batterieüberwachung</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Batterieüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Warnung:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Niedriger Ladezustand bei:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Symbole des Themas verwenden:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Aufladen</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Bei niedrigem Ladezustand:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Symbol anzeigen:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>eingebaut</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Ladung: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>&amp;Leerlaufüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="38"/>
        <source>When idle then:</source>
        <translation>Bei Leerlauf:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="57"/>
        <source>Idle time:</source>
        <translation>Inaktivitätsdauer:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="70"/>
        <source> minutes</source>
        <translation> Minuten</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Deckelüberwachung aktivieren</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed</source>
        <translation>Aktion bei geschlossenem Deckel</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery</source>
        <translation>Batteriebetrieb</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC</source>
        <translation>Am Netz</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Bei &amp;Verwendung eines externen Bildschirms</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Power Management Settings</source>
        <translation>Einstellungen der Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="39"/>
        <source>Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Lid</source>
        <translation>Deckel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation>Bildschirm(e) ausschalten</translation>
    </message>
</context>
</TS>

==> lxqt-powermanagement-0.15.0.tar.xz: lxqt-powermanagement-0.15.0/config/translations/lxqt-config-powermanagement_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Einstellungen zur Batterieüberwachung</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>&amp;Aktiviere Batterieüberwachung</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Warnung:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Niedriger Ladezustand bei:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Nutze Symbole des Themas:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Aufladen</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Entladen</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Bei niedrigem Ladestand:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Symbol anzeigen:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>eingebaut</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Ladezustand: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>&amp;Aktiviere Leerlaufüberwachung</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="38"/>
        <source>When idle then:</source>
        <translation>Bei Leerlauf:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="57"/>
        <source>Idle time:</source>
        <translation>Leerlaufzeit:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="70"/>
        <source> minutes</source>
        <translation> Minuten</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="83"/>
        <source> seconds</source>
        <translation> Sekunden</translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>&amp;Aktiviere Deckelüberwachung</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed</source>
        <translation>Aktion bei geschlossenem Deckel</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery</source>
        <translation>Batteriebetrieb</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC</source>
        <translation>Am Netz</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Bei &amp;Verwendung eines externen Bildschirms</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Power Management Settings</source>
        <translation>Einstellungen der Energieverwaltung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="39"/>
        <source>Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="43"/>
        <source>Lid</source>
        <translation>Deckel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Idle</source>
        <translation>Leerlauf</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Nichts</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Lock screen</source>
        <translation>Sperre Bildschirm</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Turn Off monitor(s)</source>
        <translation>Bildschirm(e) ausschalten</translation>
    </message>
</context>
</TS>
